@@ -18,13 +18,12 @@ package config
 
 import (
 	"errors"
-	"fmt"
 
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"k8s.io/minikube/pkg/addons"
+	"k8s.io/minikube/pkg/minikube/assets"
 	"k8s.io/minikube/pkg/minikube/config"
-	"k8s.io/minikube/pkg/minikube/constants"
 	"k8s.io/minikube/pkg/minikube/exit"
 	"k8s.io/minikube/pkg/minikube/out"
 	"k8s.io/minikube/pkg/minikube/reason"
@@ -41,16 +40,31 @@ var addonsEnableCmd = &cobra.Command{
 			exit.Message(reason.Usage, "usage: minikube addons enable ADDON_NAME")
 		}
 		addon := args[0]
-		// replace heapster as metrics-server because heapster is deprecated
-		if addon == "heapster" {
-			out.Styled(style.Waiting, "using metrics-server addon, heapster is deprecated")
-			addon = "metrics-server"
+		isDeprecated, replacement, msg := addons.Deprecations(addon)
+		if isDeprecated && replacement == "" {
+			exit.Message(reason.InternalAddonEnable, msg)
+		} else if isDeprecated {
+			out.Styled(style.Waiting, msg)
+			addon = replacement
 		}
-		if addon == "ambassador" {
-			out.Styled(style.Warning, "The ambassador addon has stopped working as of v1.23.0, for more details visit: https://github.com/datawire/ambassador-operator/issues/73")
-		}
-		if addon == "olm" {
-			out.Styled(style.Warning, "The OLM addon has stopped working, for more details visit: https://github.com/operator-framework/operator-lifecycle-manager/issues/2534")
+		addonBundle, ok := assets.Addons[addon]
+		if ok {
+			maintainer := addonBundle.Maintainer
+			if maintainer == "Google" || maintainer == "Kubernetes" {
+				out.Styled(style.Tip, `{{.addon}} is an addon maintained by {{.maintainer}}. For any concerns contact minikube on GitHub.
+You can view the list of minikube maintainers at: https://github.com/kubernetes/minikube/blob/master/OWNERS`,
+					out.V{"addon": addon, "maintainer": maintainer})
+			} else {
+				out.Styled(style.Warning, `{{.addon}} is a 3rd party addon and is not maintained or verified by minikube maintainers, enable at your own risk.`,
+					out.V{"addon": addon})
+				if addonBundle.VerifiedMaintainer != "" {
+					out.Styled(style.Tip, `{{.addon}} is maintained by {{.maintainer}} for any concerns contact {{.verifiedMaintainer}} on GitHub.`,
+						out.V{"addon": addon, "maintainer": maintainer, "verifiedMaintainer": addonBundle.VerifiedMaintainer})
+				} else {
+					out.Styled(style.Warning, `{{.addon}} does not currently have an associated maintainer.`,
+						out.V{"addon": addon})
+				}
+			}
 		}
 		viper.Set(config.AddonImages, images)
 		viper.Set(config.AddonRegistries, registries)
@@ -58,41 +72,6 @@ var addonsEnableCmd = &cobra.Command{
 		if err != nil && !errors.Is(err, addons.ErrSkipThisAddon) {
 			exit.Error(reason.InternalAddonEnable, "enable failed", err)
 		}
-		if addon == "dashboard" {
-			tipProfileArg := ""
-			if ClusterFlagValue() != constants.DefaultClusterName {
-				tipProfileArg = fmt.Sprintf(" -p %s", ClusterFlagValue())
-			}
-			out.Styled(style.Tip, `Some dashboard features require the metrics-server addon. To enable all features please run:
-
-	minikube{{.profileArg}} addons enable metrics-server	
-
-`, out.V{"profileArg": tipProfileArg})
-
-		}
-		if addon == "headlamp" {
-			out.Styled(style.Tip, `To access Headlamp, use the following command:
-minikube service headlamp -n headlamp
-
-`)
-			out.Styled(style.Tip, `To authenticate in Headlamp, fetch the Authentication Token using the following command:
-
-export SECRET=$(kubectl get secrets --namespace headlamp -o custom-columns=":metadata.name" | grep "headlamp-token")
-kubectl get secret $SECRET --namespace headlamp --template=\{\{.data.token\}\} | base64 --decode
-			
-`)
-
-			tipProfileArg := ""
-			if ClusterFlagValue() != constants.DefaultClusterName {
-				tipProfileArg = fmt.Sprintf(" -p %s", ClusterFlagValue())
-			}
-			out.Styled(style.Tip, `Headlamp can display more detailed information when metrics-server is installed. To install it, run:
-
-minikube{{.profileArg}} addons enable metrics-server	
-
-`, out.V{"profileArg": tipProfileArg})
-
-		}
 		if err == nil {
 			out.Step(style.AddonEnable, "The '{{.addonName}}' addon is enabled", out.V{"addonName": addon})
 		}
