@@ -19,6 +19,7 @@ package download
 import (
 	"fmt"
 	"io/fs"
+	"os"
 	"sync"
 	"testing"
 	"time"
@@ -35,6 +36,7 @@ func TestDownload(t *testing.T) {
 	t.Run("PreloadNotExists", testPreloadNotExists)
 	t.Run("PreloadChecksumMismatch", testPreloadChecksumMismatch)
 	t.Run("PreloadExistsCaching", testPreloadExistsCaching)
+	t.Run("PreloadWithCachedSizeZero", testPreloadWithCachedSizeZero)
 }
 
 // Returns a mock function that sleeps before incrementing `downloadsCounter` and creates the requested file.
@@ -80,12 +82,20 @@ func testBinaryDownloadPreventsMultipleDownload(t *testing.T) {
 func testPreloadDownloadPreventsMultipleDownload(t *testing.T) {
 	downloadNum := 0
 	DownloadMock = mockSleepDownload(&downloadNum)
+	f, err := os.CreateTemp("", "preload")
+	if err != nil {
+		t.Fatalf("failed to create temp file: %v", err)
+	}
+	defer os.Remove(f.Name())
+	if _, err := f.Write([]byte("data")); err != nil {
+		t.Fatalf("failed to write to temp file: %v", err)
+	}
 
 	checkCache = func(file string) (fs.FileInfo, error) {
 		if downloadNum == 0 {
 			return nil, fmt.Errorf("some error")
 		}
-		return nil, nil
+		return os.Stat(f.Name())
 	}
 	checkPreloadExists = func(k8sVersion, containerRuntime, driverName string, forcePreload ...bool) bool { return true }
 	getChecksum = func(k8sVersion, containerRuntime string) ([]byte, error) { return []byte("check"), nil }
@@ -94,7 +104,7 @@ func testPreloadDownloadPreventsMultipleDownload(t *testing.T) {
 	var group sync.WaitGroup
 	group.Add(2)
 	dlCall := func() {
-		if err := Preload(constants.DefaultKubernetesVersion, constants.DefaultContainerRuntime, "docker"); err != nil {
+		if err := Preload(constants.DefaultKubernetesVersion, constants.Docker, "docker"); err != nil {
 			t.Logf("Failed to download preload: %+v (may be ok)", err)
 		}
 		group.Done()
@@ -119,7 +129,7 @@ func testPreloadNotExists(t *testing.T) {
 	getChecksum = func(k8sVersion, containerRuntime string) ([]byte, error) { return []byte("check"), nil }
 	ensureChecksumValid = func(k8sVersion, containerRuntime, path string, checksum []byte) error { return nil }
 
-	err := Preload(constants.DefaultKubernetesVersion, constants.DefaultContainerRuntime, "docker")
+	err := Preload(constants.DefaultKubernetesVersion, constants.Docker, "docker")
 	if err != nil {
 		t.Errorf("Expected no error when preload exists")
 	}
@@ -140,7 +150,7 @@ func testPreloadChecksumMismatch(t *testing.T) {
 		return fmt.Errorf("checksum mismatch")
 	}
 
-	err := Preload(constants.DefaultKubernetesVersion, constants.DefaultContainerRuntime, "docker")
+	err := Preload(constants.DefaultKubernetesVersion, constants.Docker, "docker")
 	expectedErrMsg := "checksum mismatch"
 	if err == nil {
 		t.Errorf("Expected error when checksum mismatches")
@@ -236,3 +246,25 @@ func testPreloadExistsCaching(t *testing.T) {
 		t.Errorf("Expected preload to exist and no check to be performed. Existence: %v, Check: %v", existence, checkCalled)
 	}
 }
+
+func testPreloadWithCachedSizeZero(t *testing.T) {
+	downloadNum := 0
+	DownloadMock = mockSleepDownload(&downloadNum)
+	f, err := os.CreateTemp("", "preload")
+	if err != nil {
+		t.Fatalf("failed to create temp file: %v", err)
+	}
+
+	checkCache = func(file string) (fs.FileInfo, error) { return os.Stat(f.Name()) }
+	checkPreloadExists = func(k8sVersion, containerRuntime, driverName string, forcePreload ...bool) bool { return true }
+	getChecksum = func(k8sVersion, containerRuntime string) ([]byte, error) { return []byte("check"), nil }
+	ensureChecksumValid = func(k8sVersion, containerRuntime, path string, checksum []byte) error { return nil }
+
+	if err := Preload(constants.DefaultKubernetesVersion, constants.Docker, "docker"); err != nil {
+		t.Errorf("Expected no error with cached preload of size zero")
+	}
+
+	if downloadNum != 1 {
+		t.Errorf("Expected only 1 download attempt but got %v!", downloadNum)
+	}
+}
